Coverage report

File |  | statements | missing | excluded |  | coverage
--- | --- | --- | --- | --- | --- | ---
little_loops / cli / auto.py |  | 27 | 18 | 0 |  | 33%
little_loops / cli / deps.py |  | 152 | 147 | 0 |  | 3%
little_loops / cli / docs.py |  | 47 | 42 | 0 |  | 11%
little_loops / cli / gitignore.py |  | 36 | 29 | 0 |  | 19%
little_loops / cli / history.py |  | 69 | 63 | 0 |  | 9%
little_loops / cli / issues / append_log.py |  | 12 | 12 | 2 |  | 0%
little_loops / cli / issues / count_cmd.py |  | 23 | 23 | 2 |  | 0%
little_loops / cli / issues / impact_effort.py |  | 126 | 126 | 3 |  | 0%
little_loops / cli / issues / list_cmd.py |  | 77 | 77 | 2 |  | 0%
little_loops / cli / issues / next_id.py |  | 7 | 7 | 2 |  | 0%
little_loops / cli / issues / refine_status.py |  | 233 | 233 | 3 |  | 0%
little_loops / cli / issues / search.py |  | 216 | 216 | 3 |  | 0%
little_loops / cli / issues / sequence.py |  | 36 | 36 | 2 |  | 0%
little_loops / cli / issues / show.py |  | 217 | 217 | 2 |  | 0%
little_loops / cli / loop / _helpers.py |  | 268 | 245 | 3 |  | 9%
little_loops / cli / loop / config_cmds.py |  | 42 | 42 | 0 |  | 0%
little_loops / cli / loop / info.py |  | 504 | 480 | 0 |  | 5%
little_loops / cli / loop / layout.py |  | 934 | 900 | 0 |  | 4%
little_loops / cli / loop / lifecycle.py |  | 137 | 137 | 0 |  | 0%
little_loops / cli / loop / run.py |  | 100 | 100 | 0 |  | 0%
little_loops / cli / loop / testing.py |  | 152 | 152 | 0 |  | 0%
little_loops / cli / messages.py |  | 82 | 76 | 0 |  | 7%
little_loops / cli / output.py |  | 29 | 14 | 2 |  | 52%
little_loops / cli / parallel.py |  | 63 | 53 | 0 |  | 16%
little_loops / cli / sprint / _helpers.py |  | 134 | 128 | 4 |  | 4%
little_loops / cli / sprint / create.py |  | 35 | 29 | 0 |  | 17%
little_loops / cli / sprint / edit.py |  | 92 | 84 | 0 |  | 9%
little_loops / cli / sprint / manage.py |  | 131 | 119 | 0 |  | 9%
little_loops / cli / sprint / run.py |  | 285 | 264 | 3 |  | 7%
little_loops / cli / sprint / show.py |  | 142 | 131 | 3 |  | 8%
little_loops / cli / sync.py |  | 133 | 122 | 0 |  | 8%
little_loops / cli_args.py |  | 77 | 54 | 0 |  | 30%
little_loops / config / automation.py |  | 67 | 7 | 0 |  | 90%
little_loops / config / cli.py |  | 54 | 6 | 0 |  | 89%
little_loops / config / core.py |  | 140 | 68 | 0 |  | 51%
little_loops / config / features.py |  | 85 | 22 | 0 |  | 74%
little_loops / dependency_graph.py |  | 168 | 138 | 3 |  | 18%
little_loops / dependency_mapper / analysis.py |  | 173 | 173 | 3 |  | 0%
little_loops / dependency_mapper / formatting.py |  | 127 | 127 | 3 |  | 0%
little_loops / dependency_mapper / models.py |  | 39 | 39 | 0 |  | 0%
little_loops / dependency_mapper / operations.py |  | 124 | 124 | 3 |  | 0%
little_loops / doc_counts.py |  | 113 | 113 | 0 |  | 0%
little_loops / frontmatter.py |  | 41 | 34 | 0 |  | 17%
little_loops / fsm / concurrency.py |  | 122 | 89 | 0 |  | 27%
little_loops / fsm / evaluators.py |  | 258 | 228 | 0 |  | 12%
little_loops / fsm / executor.py |  | 393 | 327 | 0 |  | 17%
little_loops / fsm / handoff_handler.py |  | 32 | 15 | 0 |  | 53%
little_loops / fsm / interpolation.py |  | 116 | 87 | 0 |  | 25%
little_loops / fsm / persistence.py |  | 227 | 171 | 0 |  | 25%
little_loops / fsm / schema.py |  | 248 | 159 | 0 |  | 36%
little_loops / fsm / signal_detector.py |  | 31 | 11 | 0 |  | 65%
little_loops / fsm / validation.py |  | 149 | 121 | 0 |  | 19%
little_loops / git_operations.py |  | 186 | 147 | 0 |  | 21%
little_loops / goals_parser.py |  | 81 | 81 | 0 |  | 0%
little_loops / issue_discovery / extraction.py |  | 106 | 106 | 2 |  | 0%
little_loops / issue_discovery / matching.py |  | 70 | 70 | 2 |  | 0%
little_loops / issue_discovery / search.py |  | 166 | 166 | 3 |  | 0%
little_loops / issue_history / _utils.py |  | 10 | 10 | 0 |  | 0%
little_loops / issue_history / analysis.py |  | 66 | 66 | 0 |  | 0%
little_loops / issue_history / coupling.py |  | 69 | 69 | 0 |  | 0%
little_loops / issue_history / debt.py |  | 187 | 187 | 0 |  | 0%
little_loops / issue_history / doc_synthesis.py |  | 150 | 150 | 0 |  | 0%
little_loops / issue_history / formatting.py |  | 659 | 659 | 0 |  | 0%
little_loops / issue_history / hotspots.py |  | 56 | 56 | 0 |  | 0%
little_loops / issue_history / models.py |  | 302 | 302 | 0 |  | 0%
little_loops / issue_history / parsing.py |  | 152 | 152 | 0 |  | 0%
little_loops / issue_history / quality.py |  | 196 | 196 | 0 |  | 0%
little_loops / issue_history / regressions.py |  | 63 | 63 | 0 |  | 0%
little_loops / issue_history / summary.py |  | 116 | 116 | 0 |  | 0%
little_loops / issue_lifecycle.py |  | 264 | 236 | 0 |  | 11%
little_loops / issue_manager.py |  | 382 | 334 | 0 |  | 13%
little_loops / issue_parser.py |  | 256 | 192 | 2 |  | 25%
little_loops / issue_template.py |  | 56 | 48 | 0 |  | 14%
little_loops / link_checker.py |  | 183 | 183 | 0 |  | 0%
little_loops / logger.py |  | 60 | 35 | 2 |  | 42%
little_loops / logo.py |  | 12 | 12 | 0 |  | 0%
little_loops / mcp_call.py |  | 131 | 131 | 2 |  | 0%
little_loops / output_parsing.py |  | 185 | 171 | 0 |  | 8%
little_loops / parallel / file_hints.py |  | 135 | 105 | 2 |  | 22%
little_loops / parallel / git_lock.py |  | 55 | 41 | 2 |  | 25%
little_loops / parallel / merge_coordinator.py |  | 451 | 405 | 2 |  | 10%
little_loops / parallel / orchestrator.py |  | 568 | 520 | 2 |  | 8%
little_loops / parallel / overlap_detector.py |  | 56 | 35 | 3 |  | 38%
little_loops / parallel / priority_queue.py |  | 103 | 70 | 3 |  | 32%
little_loops / parallel / types.py |  | 136 | 19 | 2 |  | 86%
little_loops / parallel / worker_pool.py |  | 466 | 415 | 4 |  | 11%
little_loops / session_log.py |  | 46 | 35 | 0 |  | 24%
little_loops / sprint.py |  | 127 | 76 | 3 |  | 40%
little_loops / state.py |  | 82 | 49 | 0 |  | 40%
little_loops / subprocess_utils.py |  | 80 | 63 | 0 |  | 21%
little_loops / sync.py |  | 455 | 387 | 3 |  | 15%
little_loops / text_utils.py |  | 44 | 44 | 0 |  | 0%
little_loops / user_messages.py |  | 303 | 256 | 0 |  | 16%
little_loops / work_verification.py |  | 40 | 34 | 2 |  | 15%
little_loops / workflow_sequence_analyzer.py |  | 444 | 444 | 2 |  | 0%
Total |  | 15080 | 13371 | 91 |  | 11%

No items found using the specified filter.